OC.L10N.register(
    "lib",
    {
    "Help" : "Hjelp",
    "Personal" : "Personleg",
    "Users" : "Brukarar",
    "Admin" : "Administrer",
    "Unknown filetype" : "Ukjend filtype",
    "Invalid image" : "Ugyldig bilete",
    "today" : "i dag",
    "yesterday" : "i går",
    "last month" : "førre månad",
    "last year" : "i fjor",
    "seconds ago" : "sekund sidan",
    "web services under your control" : "Vev tjenester under din kontroll",
    "Authentication error" : "Feil i autentisering",
    "%s shared »%s« with you" : "%s delte «%s» med deg",
    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
    "A valid password must be provided" : "Du må oppgje eit gyldig passord"
},
"nplurals=2; plural=(n != 1);");
